package com.todottl.ui.screen

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.IconButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.todottl.R
import com.todottl.data.Constant

@Composable
fun AddScreen(navController: NavController) {
    var categoryData by remember { mutableIntStateOf(0) }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFF1F5F9))
    ) {
        Image(
            painter = painterResource(id = R.mipmap.add_header),
            modifier = Modifier
                .fillMaxWidth()
                .height(96.dp),
            contentScale = ContentScale.Crop,
            contentDescription = ""
        )
        Row(
            modifier = Modifier.padding(horizontal = 16.dp, vertical = 24.dp),
            verticalAlignment = Alignment.CenterVertically
        ) {
            IconButton(onClick = { navController.popBackStack() }) {
                Image(
                    painter = painterResource(id = R.mipmap.close),
                    modifier = Modifier.size(48.dp),
                    contentDescription = ""
                )
            }
            Text(
                "Add New Task",
                fontSize = 16.sp,
                fontWeight = FontWeight.Bold,
                color = Color.White,
                modifier = Modifier
                    .padding(end = 24.dp)
                    .weight(1f),
                textAlign = TextAlign.Center
            )
        }

        Column(
            modifier = Modifier
                .padding(start = 16.dp, end = 16.dp, top = 96.dp)
                .fillMaxSize()
        ) {
            val colors = TextFieldDefaults.colors(
                focusedTextColor = Color.Unspecified,
                unfocusedTextColor = Color.Unspecified,
                disabledTextColor = Color.Gray,
                errorTextColor = Color.Unspecified,
                focusedContainerColor = Color.White,
                unfocusedContainerColor = Color.White,
                disabledContainerColor = Color.Unspecified,
                errorContainerColor = Color.Unspecified,
                cursorColor = Color.Unspecified,
                errorCursorColor = Color.Unspecified,
                focusedIndicatorColor = Color.Transparent,
                unfocusedIndicatorColor = Color.Transparent,
                errorIndicatorColor = Color.Red,
            )
            FromLabel("Task Title")
            TextField(
                placeholder = {
                    Text(
                        "Task Title", fontSize = 16.sp, modifier = Modifier.alpha(0.7f)
                    )
                },
                value = "",
                onValueChange = {},
                modifier = Modifier
                    .fillMaxWidth()
                    .height(55.dp),
                shape = RoundedCornerShape(6.dp),
                colors = colors
            )
            Row(
                modifier = Modifier
                    .padding(top = 24.dp)
                    .height(48.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                FromLabel("Category", 0.dp)
                Spacer(modifier = Modifier.width(24.dp))
                Constant.imageList.forEachIndexed { index, item ->
                    var modifier = Modifier
                        .size(48.dp)

                    if (categoryData == index) {
                        modifier = Modifier
                            .size(48.dp)
                            .border(
                                width = 2.dp, color = Color.White, shape = RoundedCornerShape(48.dp)
                            )
                    }
                    IconButton(
                        onClick = {
                            categoryData = index
                        }, modifier = modifier
                    ) {
                        Image(
                            painter = painterResource(id = item),
                            contentDescription = "",
                            modifier = Modifier.fillMaxSize()
                        )
                    }
                    if (index < Constant.imageList.size - 1) {
                        Spacer(modifier = Modifier.width(16.dp))
                    }
                }
            }
            Row {
                Column(modifier = Modifier.weight(1f)) {
                    FromLabel("Date")
                    TextField(placeholder = {
                        Text(
                            "Date", fontSize = 16.sp, modifier = Modifier.alpha(0.7f)
                        )
                    },
                        value = "",
                        onValueChange = {},
                        modifier = Modifier
                            .fillMaxWidth()
                            .height(55.dp),
                        shape = RoundedCornerShape(6.dp),
                        colors = colors,
                        trailingIcon = {
                            Image(
                                painter = painterResource(id = R.mipmap.calendar),
                                contentDescription = "",
                                modifier = Modifier.size(20.dp)
                            )
                        })
                }
                Spacer(modifier = Modifier.width(8.dp))
                Column(modifier = Modifier.weight(1f)) {
                    FromLabel("Time")
                    TextField(placeholder = {
                        Text(
                            "Time", fontSize = 16.sp, modifier = Modifier.alpha(0.7f)
                        )
                    },
                        value = "",
                        onValueChange = {},
                        modifier = Modifier
                            .fillMaxWidth()
                            .height(55.dp),
                        shape = RoundedCornerShape(6.dp),
                        colors = colors,
                        trailingIcon = {
                            Image(
                                painter = painterResource(id = R.mipmap.clock),
                                contentDescription = "",
                                modifier = Modifier.size(20.dp)
                            )
                        })

                }
            }
            FromLabel("Notes")
            TextField(
                placeholder = {
                    Text(
                        "Notes", fontSize = 16.sp, modifier = Modifier.alpha(0.7f)
                    )
                },
                value = "",
                maxLines = 5,
                onValueChange = {},
                modifier = Modifier
                    .fillMaxWidth()
                    .height(177.dp),
                shape = RoundedCornerShape(6.dp),
                colors = colors
            )
        }

        Button(
            onClick = {
                // navController.navigate(RouteConfig.ADD)
            },
            modifier = Modifier
                .align(Alignment.BottomCenter)
                .padding(start = 16.dp, end = 16.dp, bottom = 24.dp)
                .fillMaxWidth()
                .height(56.dp),
            shape = RoundedCornerShape(50.dp)
        ) {
            Text(text = "Save")
        }
    }
}

@Composable
fun FromLabel(title: String, top: Dp = 24.dp) {
    Text(
        title,
        fontSize = 14.sp,
        fontWeight = FontWeight.Bold,
        color = Color.Black,
        modifier = Modifier.padding(top = top, bottom = 8.dp)
    )
}